@@ -1,8 +1,12 @@
-/*
+/***************************************************************************
  *
- * $Id: cipherfil.h,v 1.9 2002/10/01 19:52:40 dglassey Exp $
+ * cipherfil.h -	class CipherFilter: an EncodingFilter which can
+ * 			encipher and decipher a text stream based on
+ * 			a CipherKey
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: cipherfil.h 3787 2020-08-30 12:00:38Z scribe $
+ *
+ * Copyright 1999-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -22,18 +26,17 @@
 #define CIPHERFIL_H
 
 #include <swfilter.h>
-#include <swcipher.h>
-
-#include <defs.h>
 
 SWORD_NAMESPACE_START
 
-class SWDLLEXPORT CipherFilter:public SWFilter {
+class SWCipher;
+
+class SWDLLEXPORT CipherFilter : public SWFilter {
 	SWCipher *cipher;
 public:
 	CipherFilter(const char *key);
 	virtual ~CipherFilter();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key, const SWModule * = 0);
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule * = 0);
 	virtual SWCipher *getCipher();
 };
 
