@@ -1,8 +1,10 @@
-/*
+/***************************************************************************
  *
- * $Id: gbfplain.h,v 1.9 2002/10/01 19:52:40 dglassey Exp $
+ * gbfplain.h -	class GBFPlain: a StripFilter for modules marked up in GBF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: gbfplain.h 3786 2020-08-30 11:35:14Z scribe $
+ *
+ * Copyright 1997k-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -23,17 +25,14 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
-
 SWORD_NAMESPACE_START
 
-  /** This filter converts GBF text into plain text
-  */
-class SWDLLEXPORT GBFPlain:public SWFilter
-{
+/** This filter converts GBF text to plain text
+ */
+class SWDLLEXPORT GBFPlain : public SWFilter {
 public:
-  GBFPlain ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey *key, const SWModule * = 0);
+	GBFPlain();
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
 SWORD_NAMESPACE_END
