@@ -1,8 +1,11 @@
-/*
+/***************************************************************************
  *
- * $Id: gbfrtf.h,v 1.8 2002/10/01 19:52:40 dglassey Exp $
+ * gbfrtf.h -	class GBFRTF: a RenderFilter to render RTF from modules
+ * 		marked up in GBF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: gbfrtf.h 3786 2020-08-30 11:35:14Z scribe $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -23,17 +26,14 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
-
 SWORD_NAMESPACE_START
 
-  /** This filter converts GBF text into RTF text
-  */
-class SWDLLEXPORT GBFRTF:public SWFilter
-{
+/** This filter converts GBF text into RTF text
+ */
+class SWDLLEXPORT GBFRTF : public SWFilter {
 public:
-  GBFRTF ();
-  virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
+	GBFRTF();
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
 SWORD_NAMESPACE_END
