@@ -1,10 +1,12 @@
 /******************************************************************************
- *  swcacher.h	- definition of class SWCacher used to provide an interface for
- *  	objects that cache and want a standard interface for cleaning up.
  *
- * $Id: swcacher.h,v 1.3 2002/10/01 19:52:40 dglassey Exp $
+ * swcacher.h -		class SWCacher: used to provide an
+ *			interface for objects that cache and want a standard
+ *			interface for cleaning up.
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: swcacher.h 3786 2020-08-30 11:35:14Z scribe $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -27,7 +29,10 @@
 
 SWORD_NAMESPACE_START
 
-class SWDLLEXPORT  SWCacher {
+/** used to provide an interface for objects that cache and want
+ *	a standard interface for cleaning up.
+ */
+class SWDLLEXPORT SWCacher {
 public:
 	SWCacher();
 	virtual ~SWCacher();
