@@ -1,7 +1,11 @@
-/*
+/******************************************************************************
  *
+ * utf16utf8.h -	class UTF16UTF8: an EncodingFilter to convert
+ * 			UTF16 to UTF8
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: utf16utf8.h 3786 2020-08-30 11:35:14Z scribe $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -22,16 +26,14 @@
 
 #include <swfilter.h>
 
-#include <defs.h>
-
 SWORD_NAMESPACE_START
 
-  /** This filter converts UTF-16 encoded text to UTF-8
-  */
-class SWDLLEXPORT UTF16UTF8:public SWFilter {
+/** This filter converts UTF-16 encoded text to UTF-8
+ */
+class SWDLLEXPORT UTF16UTF8 : public SWFilter {
 public:
-  UTF16UTF8();
-  virtual char ProcessText (char *text, int maxlen, const SWKey *key, const SWModule * = 0);
+	UTF16UTF8();
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
 SWORD_NAMESPACE_END
